// src/c-skip-nav.tsx
import { createVNode as _createVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed } from "vue";
import { chakra, useStyleConfig } from "@chakra-ui/vue-system";
import { getValidChildren } from "@chakra-ui/vue-utils";
var FALLBACK_ID = "chakra-skip-nav";
var CSkipNavLink = defineComponent({
  name: "CSkipNavLink",
  props: {
    id: {
      type: String,
      default: FALLBACK_ID
    }
  },
  setup(props, {
    slots,
    attrs
  }) {
    const styles = useStyleConfig("SkipLink", computed(() => props));
    const skipLinkStyles = computed(() => {
      return {
        userSelect: "none",
        border: "0",
        borderRadius: "md",
        fontWeight: "semibold",
        height: "1px",
        width: "1px",
        margin: "-1px",
        padding: "0",
        outline: "0",
        overflow: "hidden",
        position: "absolute",
        clip: "rect(0 0 0 0)",
        ...styles.value,
        _focus: {
          clip: "auto",
          width: "auto",
          height: "auto",
          boxShadow: "outline",
          padding: "1rem",
          position: "fixed",
          top: "1.5rem",
          insetStart: "1.5rem"
        }
      };
    });
    return () => {
      return _createVNode(chakra.a, _mergeProps({
        "href": `#${props.id}`,
        "__css": skipLinkStyles.value
      }, attrs), {
        default: () => getValidChildren(slots)
      });
    };
  }
});
var CSkipNavContent = defineComponent({
  name: "CSkipNavContent",
  props: {
    id: {
      type: String,
      default: FALLBACK_ID
    }
  },
  setup(props, {
    attrs,
    slots
  }) {
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "tabindex": "-1",
        "id": props.id,
        "data-testid": FALLBACK_ID
      }, attrs), {
        default: () => getValidChildren(slots)
      });
    };
  }
});

export {
  CSkipNavLink,
  CSkipNavContent
};
